@@ -4,7 +4,9 @@
 # BSD License (see LICENSE for details)
 #
 import unittest
+import random
 
+import bulbs.utils
 from bulbs.config import Config, DEBUG, ERROR
 from bulbs.element import Vertex, VertexProxy, Edge, EdgeProxy       
 from .testcase import BulbsTestCase
@@ -48,3 +50,16 @@ class IndexTestCase(BulbsTestCase):
   
         self.indicesV.delete(index_name)
 
+    def test_ascii_encoding_index_lookup(self):
+        # Fixed for Neo4j Server. Still having issues with Rexster...
+        # https://github.com/espeed/bulbs/issues/117
+        # using default index name because that's what create_indexed_vertex() uses
+        name = u'Aname M\xf6ller' + bulbs.utils.to_string(random.random())
+        index_name = Vertex.get_index_name(self.vertices.client.config)
+        self.vertices.client.config.set_logger(ERROR)
+        self.vertices.index = self.indicesV.get_or_create(index_name)
+        v1a = self.vertices.create(name=name)
+        v1b = self.vertices.index.lookup(u"name", name)
+        assert next(v1b).name == name
+
+
